@@ -225,14 +225,25 @@ def kurtosis(returns):
 
 def max_drawdown(returns):
     """Calculates the maximum drawdown"""
-    ##can just get drawdown_series and take the minimun?
-    prices = utils.to_quotes(returns, 1)
-    return (prices / prices.expanding(min_periods=0).max()).min() - 1
+    dd = utils.to_drawdown_series(returns)
+    return dd.min()
 
-def longest_drawdown(returns):
+def avg_drawdown(dd_details):
+    """Calculates the maximum drawdown"""
+    res = {}
+    for c in dd_details.columns.get_level_values(0).unique():
+      res[c] = dd_details[c]['max drawdown'].mean()/100
+    return pd.DataFrame(res, index=[0]).squeeze(axis=0)
+  
+def longest_drawdown_days(returns):
     """Calculates the maximum drawdown"""
     dd = utils.to_drawdown_series(returns) < 0
     return utils.count_consecutive(dd).max()
+
+def avg_drawdown_days(returns):
+    """Calculates the maximum drawdown"""
+    dd = utils.to_drawdown_series(returns) < 0
+    return utils.count_consecutive(dd).mean()
   
 def ulcer_index(returns):
     """Calculates the ulcer index score (downside risk measurment)"""
@@ -384,17 +395,18 @@ def beta(returns, benchmark ):
   res = {}
   for c in returns:
     res[c] = matrix[c].iloc[-1]/ matrix.iloc[-1,-1]
-  return pd.DataFrame(res, index=[0])
+  return pd.DataFrame(res, index=[0]).squeeze(axis=0)
+
 
 def alpha(returns, benchmark, periods=252):
   """Calculates alpha of the portfolio"""
-
   # find beta
   _beta = beta(returns, benchmark)
-
   # calculates measures now
-  alpha = returns.mean() - _beta * benchmark.mean()
-  return alpha * periods
+  res = {}
+  for c in returns:
+    res[c] = (returns[c].mean() - _beta[c] * benchmark.mean().values[0] )* periods
+  return pd.DataFrame(res, index=[0]).squeeze(axis=0)
 
 def rolling_greeks(returns, benchmark, periods=252):
   """Calculates rolling alpha and beta of the portfolio"""
